@@ -1,7 +1,9 @@
-#! /usr/bin/python
+#! /usr/bin/env python
 # -*- coding: UTF-8 -*-
 from __future__ import division
-import os, sys, re
+import os
+import sys
+import re
 
 # Assumes SolidPython is in site-packages or elsewhwere in sys.path
 from solid import *
@@ -13,9 +15,9 @@ SEGMENTS = 48
 def assembly():
     # Your code here!
     a = union()
-    
+
     return a
 
 if __name__ == '__main__':
-    a = assembly()    
-    scad_render_to_file( a, file_header='$fn = %s;'%SEGMENTS, include_orig_code=True)
+    a = assembly()
+    scad_render_to_file(a, file_header='$fn = %s;' % SEGMENTS, include_orig_code=True)
